@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from datetime import datetime, timedelta
 from enum import Enum
-from typing import TYPE_CHECKING, Final, cast
+from typing import TYPE_CHECKING, Any, Final, cast
 
 import voluptuous as vol
 
@@ -37,7 +37,6 @@ CONF_VOICE_PROMPT_VOLUME = "voice_prompt_volume"
 
 DEFAULT_LOCK_STATE_CHANGE_WINDOW = timedelta(seconds=15)
 
-
 SYSTEM_PROPERTIES_VALUE_MAP = {
     CONF_ALARM_DURATION: "alarmDuration",
     CONF_ALARM_VOLUME: "alarmVolume",
@@ -352,6 +351,56 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
         """
         return cast(int, self.settings_data["basestationStatus"]["wifiRssi"])
 
+    async def _async_clear_notifications(self) -> None:
+        """Clear active notifications."""
+        await self._api.async_request(
+            "delete", f"ss3/subscriptions/{self.system_id}/messages"
+        )
+
+    async def _async_set_state(self, value: SystemStates) -> None:
+        """Set the state of the system."""
+        await self._api.async_request(
+            "post", f"ss3/subscriptions/{self.system_id}/state/{value.name.lower()}"
+        )
+
+        self._state = value
+        self._last_state_change_dt = datetime.utcnow()
+
+    async def _async_set_updated_pins(self, pins: dict) -> None:
+        """Post new PINs."""
+        self.settings_data = await self._api.async_request(
+            "post",
+            f"ss3/subscriptions/{self.system_id}/settings/pins",
+            json=create_pin_payload(pins),
+        )
+
+    async def _async_update_device_data(self, cached: bool = True) -> None:
+        """Update sensors to the latest values."""
+        sensor_resp = await self._api.async_request(
+            "get",
+            f"ss3/subscriptions/{self.system_id}/sensors",
+            params={"forceUpdate": str(not cached).lower()},
+        )
+        self.sensor_data = {
+            sensor["serial"]: sensor for sensor in sensor_resp.get("sensors", [])
+        }
+
+    async def _async_update_settings_data(self, cached: bool = True) -> None:
+        """Get all system settings."""
+        settings_resp = await self._api.async_request(
+            "get",
+            f"ss3/subscriptions/{self.system_id}/settings/normal",
+            params={"forceUpdate": str(not cached).lower()},
+        )
+
+        if settings_resp:
+            self.settings_data = settings_resp
+
+    async def _async_update_subscription_data(self) -> None:
+        """Update subscription data."""
+        await super()._async_update_subscription_data()
+        self.camera_data = self._generate_camera_data()
+
     def _generate_camera_data(self) -> dict[str, dict]:
         """Generate usable, hashable camera data from subscription data.
 
@@ -366,56 +415,39 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
             ].get("cameras", [])
         }
 
-    async def _async_set_state(self, value: SystemStates) -> None:
-        """Set the state of the system."""
-        await self._api.request(
-            "post", f"ss3/subscriptions/{self.system_id}/state/{value.name.lower()}"
-        )
-
-        self._state = value
-        self._last_state_change_dt = datetime.utcnow()
-
-    async def _async_set_updated_pins(self, pins: dict) -> None:
-        """Post new PINs."""
-        self.settings_data = await self._api.request(
-            "post",
-            f"ss3/subscriptions/{self.system_id}/settings/pins",
-            json=create_pin_payload(pins),
-        )
-
-    async def _async_update_device_data(self, cached: bool = True) -> None:
-        """Update sensors to the latest values."""
-        sensor_resp = await self._api.request(
-            "get",
-            f"ss3/subscriptions/{self.system_id}/sensors",
-            params={"forceUpdate": str(not cached).lower()},
-        )
-        self.sensor_data = {
-            sensor["serial"]: sensor for sensor in sensor_resp.get("sensors", [])
+    def as_dict(self) -> dict[str, Any]:
+        """Return dictionary version of this device."""
+        return {
+            **super().as_dict(),
+            "alarm_duration": self.alarm_duration,
+            "alarm_volume": self.alarm_volume.value,
+            "battery_backup_power_level": self.battery_backup_power_level,
+            "cameras": [camera.as_dict() for camera in self.cameras.values()],
+            "chime_volume": self.chime_volume.value,
+            "entry_delay_away": self.entry_delay_away,
+            "entry_delay_home": self.entry_delay_home,
+            "exit_delay_away": self.exit_delay_away,
+            "exit_delay_home": self.exit_delay_home,
+            "gsm_strength": self.gsm_strength,
+            "light": self.light,
+            "locks": [lock.as_dict() for lock in self.locks.values()],
+            "offline": self.offline,
+            "power_outage": self.power_outage,
+            "rf_jamming": self.rf_jamming,
+            "voice_prompt_volume": self.voice_prompt_volume.value,
+            "wall_power_level": self.wall_power_level,
+            "wifi_ssid": self.wifi_ssid,
+            "wifi_strength": self.wifi_strength,
         }
 
-    async def _async_update_settings_data(self, cached: bool = True) -> None:
-        """Get all system settings."""
-        settings_resp = await self._api.request(
-            "get",
-            f"ss3/subscriptions/{self.system_id}/settings/normal",
-            params={"forceUpdate": str(not cached).lower()},
-        )
-
-        if settings_resp:
-            self.settings_data = settings_resp
-
-    async def _async_update_subscription_data(self) -> None:
-        """Update subscription data."""
-        await super()._async_update_subscription_data()
-        self.camera_data = self._generate_camera_data()
-
     def generate_device_objects(self) -> None:
         """Generate device objects for this system."""
         for serial, sensor in self.sensor_data.items():
             sensor_type = get_device_type_from_data(sensor)
             if sensor_type == DeviceTypes.LOCK:
-                self.locks[serial] = Lock(self._api.request, self, sensor_type, serial)
+                self.locks[serial] = Lock(
+                    self._api.async_request, self, sensor_type, serial
+                )
             else:
                 self.sensors[serial] = SensorV3(self, sensor_type, serial)
 
@@ -474,7 +506,7 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
                 f"Using invalid values for system properties ({properties}): {err}"
             ) from None
 
-        settings_resp = await self._api.request(
+        settings_resp = await self._api.async_request(
             "post",
             f"ss3/subscriptions/{self.system_id}/settings/normal",
             json={
